@@ -13,7 +13,6 @@
 #include <libfilezilla/process.hpp>
 
 #include <wx/log.h>
-#include <wx/tokenzr.h>
 
 #include <cwchar>
 
@@ -34,7 +33,7 @@ typedef fz::simple_event<terminate_event_type, std::wstring> CTerminateEvent;
 class CSftpFileTransferOpData : public CFileTransferOpData
 {
 public:
-	CSftpFileTransferOpData(bool is_download, const wxString& local_file, const wxString& remote_file, const CServerPath& remote_path)
+	CSftpFileTransferOpData(bool is_download, std::wstring const& local_file, std::wstring const& remote_file, CServerPath const& remote_path)
 		: CFileTransferOpData(is_download, local_file, remote_file, remote_path)
 	{
 	}
@@ -204,7 +203,7 @@ public:
 	virtual ~CSftpDeleteOpData() {}
 
 	CServerPath path;
-	std::deque<wxString> files;
+	std::deque<std::wstring> files;
 
 	// Set to fz::datetime::Now initially and after
 	// sending an updated listing to the UI.
@@ -236,25 +235,25 @@ enum connectStates
 	connect_open
 };
 
-class CSftpConnectOpData : public COpData
+class CSftpConnectOpData final : public COpData
 {
 public:
 	CSftpConnectOpData()
 		: COpData(Command::connect)
+		, keyfile_(keyfiles_.cend())
 	{
-		criticalFailure = false;
-		pKeyFiles = 0;
 	}
 
 	virtual ~CSftpConnectOpData()
 	{
-		delete pKeyFiles;
 	}
 
 	wxString lastChallenge;
-	bool criticalFailure;
+	CInteractiveLoginNotification::type lastChallengeType{CInteractiveLoginNotification::interactive};
+	bool criticalFailure{};
 
-	wxStringTokenizer* pKeyFiles;
+	std::vector<std::wstring> keyfiles_;
+	std::vector<std::wstring>::const_iterator keyfile_;
 };
 
 int CSftpControlSocket::Connect(const CServer &server)
@@ -287,16 +286,13 @@ int CSftpControlSocket::Connect(const CServer &server)
 
 	pData->opState = connect_init;
 
-	wxStringTokenizer* pTokenizer;
-	if (m_pCurrentServer->GetLogonType() == KEY)
-		pTokenizer = new wxStringTokenizer(m_pCurrentServer->GetKeyFile() + _T("\n"), _T("\n"), wxTOKEN_DEFAULT);
-	else
-		pTokenizer = new wxStringTokenizer(engine_.GetOptions().GetOption(OPTION_SFTP_KEYFILES), _T("\n"), wxTOKEN_DEFAULT);
-
-	if (!pTokenizer->HasMoreTokens())
-		delete pTokenizer;
-	else
-		pData->pKeyFiles = pTokenizer;
+	if (m_pCurrentServer->GetLogonType() == KEY) {
+		pData->keyfiles_ = fz::strtok(m_pCurrentServer->GetKeyFile(), L"\r\n");
+	}
+	else {
+		pData->keyfiles_ = fz::strtok(engine_.GetOptions().GetOption(OPTION_SFTP_KEYFILES), L"\r\n");
+	}
+	pData->keyfile_ = pData->keyfiles_.cbegin();
 
 	m_pProcess = new fz::process();
 
@@ -345,8 +341,7 @@ int CSftpControlSocket::ConnectParseResponse(bool successful, const wxString& re
 	}
 
 	CSftpConnectOpData *pData = static_cast<CSftpConnectOpData *>(m_pCurOpData);
-	if (!pData)
-	{
+	if (!pData) {
 		LogMessage(__TFILE__, __LINE__, this, MessageType::Debug_Warning, _T("m_pCurOpData of wrong type"));
 		DoClose(FZ_REPLY_INTERNALERROR);
 		return FZ_REPLY_ERROR;
@@ -360,23 +355,28 @@ int CSftpControlSocket::ConnectParseResponse(bool successful, const wxString& re
 			DoClose(FZ_REPLY_INTERNALERROR);
 			return FZ_REPLY_ERROR;
 		}
-		if (engine_.GetOptions().GetOptionVal(OPTION_PROXY_TYPE) && !m_pCurrentServer->GetBypassProxy())
+		if (engine_.GetOptions().GetOptionVal(OPTION_PROXY_TYPE) && !m_pCurrentServer->GetBypassProxy()) {
 			pData->opState = connect_proxy;
-		else if (pData->pKeyFiles)
+		}
+		else if (pData->keyfile_ != pData->keyfiles_.cend()) {
 			pData->opState = connect_keys;
-		else
+		}
+		else {
 			pData->opState = connect_open;
+		}
 		break;
 	case connect_proxy:
-		if (pData->pKeyFiles)
+		if (pData->keyfile_ != pData->keyfiles_.cend()) {
 			pData->opState = connect_keys;
-		else
+		}
+		else {
 			pData->opState = connect_open;
+		}
 		break;
 	case connect_keys:
-		wxASSERT(pData->pKeyFiles);
-		if (!pData->pKeyFiles->HasMoreTokens())
+		if (pData->keyfile_ == pData->keyfiles_.cend()) {
 			pData->opState = connect_open;
+		}
 		break;
 	case connect_open:
 		engine_.AddNotification(new CSftpEncryptionNotification(m_sftpEncryptionDetails));
@@ -435,13 +435,13 @@ int CSftpControlSocket::ConnectSend()
 			std::wstring cmd = fz::sprintf(L"proxy %d \"%s\" %d", type,
 											engine_.GetOptions().GetOption(OPTION_PROXY_HOST),
 											engine_.GetOptions().GetOptionVal(OPTION_PROXY_PORT));
-			std::wstring user = engine_.GetOptions().GetOption(OPTION_PROXY_USER).ToStdWstring();
+			std::wstring user = engine_.GetOptions().GetOption(OPTION_PROXY_USER);
 			if (!user.empty()) {
 				cmd += L" \"" + user + L"\"";
 			}
 
 			std::wstring show = cmd;
-			std::wstring pass = engine_.GetOptions().GetOption(OPTION_PROXY_PASS).ToStdWstring();
+			std::wstring pass = engine_.GetOptions().GetOption(OPTION_PROXY_PASS);
 			if (!pass.empty()) {
 				cmd += L" \"" + pass + L"\"";
 				show += L" \"" + std::wstring(pass.size(), '*') + L"\"";
@@ -450,7 +450,7 @@ int CSftpControlSocket::ConnectSend()
 		}
 		break;
 	case connect_keys:
-		res = SendCommand(L"keyfile \"" + pData->pKeyFiles->GetNextToken().ToStdWstring() + L"\"");
+		res = SendCommand(L"keyfile \"" + *(pData->keyfile_++) + L"\"");
 		break;
 	case connect_open:
 		res = SendCommand(fz::sprintf(L"open \"%s@%s\" %d", m_pCurrentServer->GetUser(), m_pCurrentServer->GetHost(), m_pCurrentServer->GetPort()));
@@ -568,8 +568,8 @@ void CSftpControlSocket::OnSftpEvent(sftp_message const& message)
 
 			wxString const challengeIdentifier = m_requestPreamble + _T("\n") + m_requestInstruction + _T("\n") + message.text[0];
 
+			CInteractiveLoginNotification::type t = CInteractiveLoginNotification::interactive;
 			if (m_pCurrentServer->GetLogonType() == INTERACTIVE || m_requestPreamble == _T("SSH key passphrase")) {
-				CInteractiveLoginNotification::type t = CInteractiveLoginNotification::interactive;
 				if (m_requestPreamble == _T("SSH key passphrase")) {
 					t = CInteractiveLoginNotification::keyfile;
 				}
@@ -587,14 +587,10 @@ void CSftpControlSocket::OnSftpEvent(sftp_message const& message)
 				CInteractiveLoginNotification *pNotification = new CInteractiveLoginNotification(t, challenge, pData->lastChallenge == challengeIdentifier);
 				pNotification->server = *m_pCurrentServer;
 
-				pData->lastChallenge = challengeIdentifier;
-
 				SendAsyncRequest(pNotification);
 			}
 			else {
-				const wxString newChallenge = m_requestPreamble + _T("\n") + m_requestInstruction + message.text[0];
-
-				if (!pData->lastChallenge.empty()) {
+				if (!pData->lastChallenge.empty() && pData->lastChallengeType != CInteractiveLoginNotification::keyfile) {
 					// Check for same challenge. Will most likely fail as well, so abort early.
 					if (pData->lastChallenge == challengeIdentifier) {
 						LogMessage(MessageType::Error, _("Authentication failed."));
@@ -606,13 +602,13 @@ void CSftpControlSocket::OnSftpEvent(sftp_message const& message)
 					return;
 				}
 
-				pData->lastChallenge = challengeIdentifier;
-
 				std::wstring const pass = m_pCurrentServer->GetPass().ToStdWstring();
 				std::wstring show = _T("Pass: ");
 				show.append(pass.size(), '*');
 				SendCommand(pass, show);
 			}
+			pData->lastChallenge = challengeIdentifier;
+			pData->lastChallengeType = t;
 		}
 		break;
 	case sftpEvent::RequestPreamble:
@@ -1470,9 +1466,9 @@ int CSftpControlSocket::SendNextCommand()
 	return FZ_REPLY_ERROR;
 }
 
-int CSftpControlSocket::FileTransfer(const wxString localFile, const CServerPath &remotePath,
-									const wxString &remoteFile, bool download,
-									const CFileTransferCommand::t_transferSettings& transferSettings)
+int CSftpControlSocket::FileTransfer(std::wstring const& localFile, CServerPath const& remotePath,
+									std::wstring const& remoteFile, bool download,
+									CFileTransferCommand::t_transferSettings const& transferSettings)
 {
 	LogMessage(MessageType::Debug_Verbose, _T("CSftpControlSocket::FileTransfer(...)"));
 
@@ -1503,8 +1499,9 @@ int CSftpControlSocket::FileTransfer(const wxString localFile, const CServerPath
 
 	int64_t size;
 	bool isLink;
-	if (fz::local_filesys::get_file_info(fz::to_native(pData->localFile), isLink, &size, 0, 0) == fz::local_filesys::file)
+	if (fz::local_filesys::get_file_info(fz::to_native(pData->localFile), isLink, &size, 0, 0) == fz::local_filesys::file) {
 		pData->localFileSize = size;
+	}
 
 	pData->opState = filetransfer_waitcwd;
 
@@ -1642,8 +1639,7 @@ int CSftpControlSocket::FileTransferSend()
 {
 	LogMessage(MessageType::Debug_Verbose, _T("FileTransferSend()"));
 
-	if (!m_pCurOpData)
-	{
+	if (!m_pCurOpData) {
 		LogMessage(__TFILE__, __LINE__, this, MessageType::Debug_Info, _T("Empty m_pCurOpData"));
 		ResetOperation(FZ_REPLY_INTERNALERROR);
 		return FZ_REPLY_ERROR;
@@ -1665,7 +1661,7 @@ int CSftpControlSocket::FileTransferSend()
 			cmd += L"get ";
 			cmd += QuoteFilename(pData->remotePath.FormatFilename(pData->remoteFile, !pData->tryAbsolutePath).ToStdWstring()) + L" ";
 
-			std::wstring localFile = QuoteFilename(pData->localFile.ToStdWstring());
+			std::wstring localFile = QuoteFilename(pData->localFile);
 			std::wstring logstr = cmd;
 			logstr += localFile;
 			LogMessageRaw(MessageType::Command, logstr);
@@ -1680,7 +1676,7 @@ int CSftpControlSocket::FileTransferSend()
 			cmd += L"put ";
 
 			std::wstring logstr = cmd;
-			std::wstring localFile = QuoteFilename(pData->localFile.ToStdWstring()) + _T(" ");
+			std::wstring localFile = QuoteFilename(pData->localFile) + L" ";
 			std::wstring remoteFile = QuoteFilename(pData->remotePath.FormatFilename(pData->remoteFile, !pData->tryAbsolutePath).ToStdWstring());
 
 			logstr += localFile;
@@ -2031,10 +2027,10 @@ int CSftpControlSocket::MkdirSend()
 
 std::wstring CSftpControlSocket::QuoteFilename(std::wstring const& filename)
 {
-	return L"\"" + fz::replace_substrings(filename, L"\"", L"\"\"") + L"\"";
+	return L"\"" + fz::replaced_substrings(filename, L"\"", L"\"\"") + L"\"";
 }
 
-int CSftpControlSocket::Delete(const CServerPath& path, std::deque<wxString>&& files)
+int CSftpControlSocket::Delete(const CServerPath& path, std::deque<std::wstring>&& files)
 {
 	LogMessage(MessageType::Debug_Verbose, _T("CSftpControlSocket::Delete"));
 	wxASSERT(!m_pCurOpData);
