@@ -50,7 +50,7 @@ public:
 	virtual int Connect(const CServer &server);
 
 	virtual int List(CServerPath path = CServerPath(), wxString subDir = _T(""), int flags = 0);
-	virtual int Delete(const CServerPath& path, std::deque<wxString>&& files);
+	virtual int Delete(const CServerPath& path, std::deque<std::wstring>&& files);
 	virtual int RemoveDir(const CServerPath& path = CServerPath(), const wxString& subDir = _T(""));
 	virtual int Mkdir(const CServerPath& path);
 	virtual int Rename(const CRenameCommand& command);
@@ -77,9 +77,9 @@ protected:
 	int ConnectParseResponse(bool successful, const wxString& reply);
 	int ConnectSend();
 
-	virtual int FileTransfer(const wxString localFile, const CServerPath &remotePath,
-							 const wxString &remoteFile, bool download,
-							 const CFileTransferCommand::t_transferSettings& transferSettings);
+	virtual int FileTransfer(std::wstring const& localFile, CServerPath const& remotePath,
+							 std::wstring const& remoteFile, bool download,
+							 CFileTransferCommand::t_transferSettings const& transferSettings);
 	int FileTransferSubcommandResult(int prevResult);
 	int FileTransferSend();
 	int FileTransferParseResponse(int result, const wxString& reply);
