@@ -1435,41 +1435,43 @@ wxString CTlsSocket::GetMacName()
 		return _T("unknown");
 }
 
-wxString CTlsSocket::ListTlsCiphers(wxString priority)
+std::string CTlsSocket::ListTlsCiphers(std::string priority)
 {
-	if (priority.empty())
-		priority = wxString::FromUTF8(ciphers);
+	if (priority.empty()) {
+		priority = ciphers;
+	}
 
-	wxString list = wxString::Format(_T("Ciphers for %s:\n"), priority);
+	auto list = fz::sprintf("Ciphers for %s:\n", priority);
 
 	gnutls_priority_t pcache;
 	const char *err = 0;
-	int ret = gnutls_priority_init(&pcache, priority.mb_str(), &err);
+	int ret = gnutls_priority_init(&pcache, priority.c_str(), &err);
 	if (ret < 0) {
-		list += wxString::Format(_T("gnutls_priority_init failed with code %d: %s"), ret, err ? wxString::FromUTF8(err) : _T("Unknown error"));
+		list += fz::sprintf("gnutls_priority_init failed with code %d: %s", ret, err ? err : "Unknown error");
 		return list;
 	}
 	else {
-		for (size_t i = 0; ; i++) {
+		for (size_t i = 0; ; ++i) {
 			unsigned int idx;
 			ret = gnutls_priority_get_cipher_suite_index(pcache, i, &idx);
-			if (ret == GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE)
+			if (ret == GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE) {
 				break;
-			if (ret == GNUTLS_E_UNKNOWN_CIPHER_SUITE)
+			}
+			if (ret == GNUTLS_E_UNKNOWN_CIPHER_SUITE) {
 				continue;
+			}
 
 			gnutls_protocol_t version;
 			unsigned char id[2];
 			const char* name = gnutls_cipher_suite_info(idx, id, NULL, NULL, NULL, &version);
 
-			if (name != 0)
-			{
-				list += wxString::Format(
-					_T("%-50s    0x%02x, 0x%02x    %s\n"),
-					wxString::FromUTF8(name),
+			if (name != 0) {
+				list += fz::sprintf(
+					"%-50s    0x%02x, 0x%02x    %s\n",
+					name,
 					(unsigned char)id[0],
 					(unsigned char)id[1],
-					wxString::FromUTF8(gnutls_protocol_get_name(version)));
+					gnutls_protocol_get_name(version));
 			}
 		}
 	}
