@@ -16,7 +16,7 @@
 #else
 	#define STDEXPORTAPI extern "C" __declspec(dllexport) HRESULT STDAPICALLTYPE
 
-	#include <config.h>
+	#include "config.h"
 #if !HAVE_ICOPYHOOKW
 	// Some versions of the MinGW w32api have no unicode version of ICopyHook. As such,
 	// declare ICopyHookW manually.
@@ -96,6 +96,20 @@ void operator delete[](void* ptr)
 	}
 }
 
+void operator delete(void* ptr, std::size_t)
+{
+	if (ptr) {
+		free(ptr);
+	}
+}
+
+void operator delete[](void* ptr, std::size_t)
+{
+	if (ptr) {
+		free(ptr);
+	}
+}
+
 //---------------------------------------------------------------------------
 class CShellExtClassFactory : public IClassFactory
 {
@@ -294,7 +308,6 @@ DllMain(HINSTANCE HInstance, DWORD Reason, LPVOID Reserved)
 #ifdef DEBUG
 		if (!GLogMutex)
 			GLogMutex = CreateMutex(NULL, false, _T("FileZilla3DragDropExtLogMutex"));
-#endif
 
 		if (GRefThisDll != 0) {
 			DEBUG_MSG("DllMain return: settings already loaded");
@@ -334,6 +347,10 @@ DllMain(HINSTANCE HInstance, DWORD Reason, LPVOID Reserved)
 		DEBUG_LOG_VERSION(HInstance);
 
 		DEBUG_MSG("DllMain leave");
+#else
+		GEnabled = true;
+#endif
+
 	}
 	else if (Reason == DLL_PROCESS_DETACH) {
 		DEBUG_MSG("DllMain detaching process");
@@ -845,6 +862,8 @@ STDMETHODIMP_(UINT) CShellExt::CopyCallback(HWND Hwnd, UINT wFunc, UINT Flags,
 				DEBUG_MSG("CShellExt::CopyCallback supported structure version");
 				if (data[1] == 1) {
 					DEBUG_MSG("CShellExt::CopyCallback dragging");
+					data[DRAG_EXT_MAPPING_LENGTH - 1] = 0;
+					data[DRAG_EXT_MAPPING_LENGTH - 2] = 0;
 
 					wchar_t* file = reinterpret_cast<wchar_t *>(data + 2);
 					DEBUG_MSG("Dragged file:");
@@ -852,12 +871,12 @@ STDMETHODIMP_(UINT) CShellExt::CopyCallback(HWND Hwnd, UINT wFunc, UINT Flags,
 
 					if (_wcsicmp(file, SrcFile) == 0) {
 						data[1] = 2;
-						if (_tcslen(DestFile) > MAX_PATH) {
-							DEBUG_MSG("CShellExt::CopyCallback length of DestFile exceeding MAX_PATH");
+						if (_tcslen(DestFile) > DRAG_EXT_MAX_PATH) {
+							DEBUG_MSG("CShellExt::CopyCallback length of DestFile exceeding DRAG_EXT_MAX_PATH");
 						}
 						else {
-							wcsncpy(file, DestFile, MAX_PATH);
-							file[MAX_PATH] = 0;
+							wcsncpy(file, DestFile, DRAG_EXT_MAX_PATH);
+							file[DRAG_EXT_MAX_PATH] = 0;
 							DEBUG_MSG("CShellExt::CopyCallback destination written into buffer");
 						}
 						Result = IDNO;
