@@ -158,18 +158,18 @@ public:
 	// For downloads, localFile can be left empty if supported by protocol.
 	// Check for nId_data notification.
 	// FIXME: localFile empty iff protocol is HTTP.
-	CFileTransferCommand(wxString const& localFile, CServerPath const& remotePath, wxString const& remoteFile, bool download, t_transferSettings const& m_transferSettings);
+	CFileTransferCommand(std::wstring const& localFile, CServerPath const& remotePath, std::wstring const& remoteFile, bool download, t_transferSettings const& m_transferSettings);
 
-	wxString GetLocalFile() const;
+	std::wstring GetLocalFile() const;
 	CServerPath GetRemotePath() const;
-	wxString GetRemoteFile() const;
+	std::wstring GetRemoteFile() const;
 	bool Download() const;
 	const t_transferSettings& GetTransferSettings() const { return m_transferSettings; }
 
 protected:
-	wxString const m_localFile;
+	std::wstring const m_localFile;
 	CServerPath const m_remotePath;
-	wxString const m_remoteFile;
+	std::wstring const m_remoteFile;
 	bool const m_download;
 	t_transferSettings const m_transferSettings;
 };
@@ -190,15 +190,16 @@ protected:
 class CDeleteCommand final : public CCommandHelper<CDeleteCommand, Command::del>
 {
 public:
-	CDeleteCommand(CServerPath const& path, std::list<wxString> const& files);
+	CDeleteCommand(CServerPath const& path, std::deque<std::wstring> && files);
 
 	CServerPath GetPath() const { return m_path; }
-	const std::list<wxString>& GetFiles() const { return m_files; }
+	const std::deque<std::wstring>& GetFiles() const { return m_files; }
+	std::deque<std::wstring>&& ExtractFiles() { return std::move(m_files); }
 
 	bool valid() const { return !GetPath().empty() && !GetFiles().empty(); }
 protected:
 	CServerPath const m_path;
-	std::list<wxString> const m_files;
+	std::deque<std::wstring> m_files;
 };
 
 class CRemoveDirCommand final : public CCommandHelper<CRemoveDirCommand, Command::removedir>
