@@ -91,7 +91,7 @@ public:
 	wxString GetUser() const;
 	wxString GetPass() const;
 	wxString GetAccount() const;
-	wxString GetKeyFile() const;
+	std::wstring GetKeyFile() const;
 	int GetTimezoneOffset() const;
 	PasvMode GetPasvMode() const;
 	int MaximumMultipleConnections() const;
@@ -149,8 +149,8 @@ public:
 
 	// Abstract server name.
 	// Not compared in ==, < and related operators
-	void SetName(const wxString& name) { m_name = name; }
-	wxString GetName() const { return m_name; }
+	void SetName(std::wstring const& name) { m_name = name; }
+	std::wstring GetName() const { return m_name; }
 
 	static wxString GetNameFromServerType(ServerType type);
 	static ServerType GetServerTypeFromName(const wxString& name);
@@ -158,6 +158,8 @@ public:
 	static wxString GetNameFromLogonType(LogonType type);
 	static LogonType GetLogonTypeFromName(const wxString& name);
 
+	explicit operator bool() const { return !m_host.empty(); }
+
 protected:
 	void Initialize();
 
@@ -169,13 +171,13 @@ protected:
 	wxString m_user;
 	wxString m_pass;
 	wxString m_account;
-	wxString m_keyFile;
+	std::wstring m_keyFile;
 	int m_timezoneOffset;
 	PasvMode m_pasvMode;
 	int m_maximumMultipleConnections;
 	CharsetEncoding m_encodingType;
 	wxString m_customEncoding;
-	wxString m_name;
+	std::wstring m_name;
 
 	std::vector<wxString> m_postLoginCommands;
 	bool m_bypassProxy;
