@@ -7,7 +7,6 @@
 #include "Options.h"
 #include "wrapengine.h"
 #include "buildinfo.h"
-#include <wx/tokenzr.h>
 #include "cmdline.h"
 #include "welcome_dialog.h"
 #include <msgbox.h>
@@ -42,7 +41,7 @@ IMPLEMENT_APP_NO_MAIN(CFileZillaApp)
 
 CFileZillaApp::CFileZillaApp()
 {
-	m_profilingActive = true;
+	m_profile_start = fz::monotonic_clock::now();
 	AddStartupProfileRecord(_T("CFileZillaApp::CFileZillaApp()"));
 }
 
@@ -141,11 +140,11 @@ void CFileZillaApp::InitLocale()
 			for( language = GetFallbackLocale(language); !language.empty(); language = GetFallbackLocale(language) ) {
 				const wxLanguageInfo* fallbackInfo = wxLocale::FindLanguageInfo(language);
 				if( fallbackInfo && SetLocale(fallbackInfo->Language )) {
-					COptions::Get()->SetOption(OPTION_LANGUAGE, language);
+					COptions::Get()->SetOption(OPTION_LANGUAGE, language.ToStdWstring());
 					return;
 				}
 			}
-			COptions::Get()->SetOption(OPTION_LANGUAGE, wxString());
+			COptions::Get()->SetOption(OPTION_LANGUAGE, std::wstring());
 			if (pInfo && !pInfo->Description.empty())
 				wxMessageBoxEx(wxString::Format(_("Failed to set language to %s (%s), using default system language"), pInfo->Description, language), _("Failed to change language"), wxICON_EXCLAMATION);
 			else
@@ -670,7 +669,7 @@ void CFileZillaApp::CheckExistsFzsftp()
 	}
 #endif
 
-	COptions::Get()->SetOption(OPTION_FZSFTP_EXECUTABLE, executable);
+	COptions::Get()->SetOption(OPTION_FZSFTP_EXECUTABLE, executable.ToStdWstring());
 }
 
 #ifdef __WXMSW__
@@ -715,31 +714,30 @@ int CFileZillaApp::ProcessCommandLine()
 
 void CFileZillaApp::AddStartupProfileRecord(const wxString& msg)
 {
-	if (!m_profilingActive)
+	if (!m_profile_start) {
 		return;
+	}
 
-	m_startupProfile.push_back(std::make_pair(wxDateTime::UNow(), msg));
+	m_startupProfile.emplace_back(fz::monotonic_clock::now(), msg);
 }
 
 void CFileZillaApp::ShowStartupProfile()
 {
-	m_profilingActive = false;
+	if (m_profile_start && m_pCommandLine && m_pCommandLine->HasSwitch(CCommandLine::debug_startup)) {
+		wxString msg = _T("Profile:\n");
+		for (auto const& p : m_startupProfile) {
+			auto const diff = p.first - m_profile_start;
 
-	std::list<std::pair<wxDateTime, wxString> > profile;
-	profile.swap(m_startupProfile);
-
-	if (m_pCommandLine && !m_pCommandLine->HasSwitch(CCommandLine::debug_startup))
-		return;
-
-	wxString msg = _T("Profile:\n");
-	for (auto const& p : profile) {
-		msg += p.first.Format(_T("%Y-%m-%d %H:%M:%S %l"));
-		msg += _T(" ");
-		msg += p.second;
-		msg += _T("\n");
+			msg += std::to_wstring(diff.get_milliseconds());
+			msg += _T(" ");
+			msg += p.second;
+			msg += _T("\n");
+		}
+		wxMessageBoxEx(msg);
 	}
 
-	wxMessageBoxEx(msg);
+	m_profile_start = fz::monotonic_clock();
+	m_startupProfile.clear();
 }
 
 wxString CFileZillaApp::GetSettingsFile(wxString const& name) const
