@@ -42,7 +42,7 @@ bool CAsyncRequestQueue::ProcessDefaults(CFileZillaEngine *pEngine, std::unique_
 			CFileExistsNotification *pFileExistsNotification = static_cast<CFileExistsNotification *>(pNotification.get());
 
 			// Get the action, go up the hierarchy till one is found
-			enum CFileExistsNotification::OverwriteAction action = pFileExistsNotification->overwriteAction;
+			CFileExistsNotification::OverwriteAction action = pFileExistsNotification->overwriteAction;
 			if (action == CFileExistsNotification::unknown)
 				action = CDefaultFileExistsDlg::GetDefault(pFileExistsNotification->download);
 			if (action == CFileExistsNotification::unknown) {
@@ -50,7 +50,7 @@ bool CAsyncRequestQueue::ProcessDefaults(CFileZillaEngine *pEngine, std::unique_
 				if (option < CFileExistsNotification::unknown || option >= CFileExistsNotification::ACTION_COUNT)
 					action = CFileExistsNotification::unknown;
 				else
-					action = (enum CFileExistsNotification::OverwriteAction)option;
+					action = static_cast<CFileExistsNotification::OverwriteAction>(option);
 			}
 
 			// Ask and rename options require user interaction
@@ -141,7 +141,12 @@ bool CAsyncRequestQueue::ProcessNextRequest()
 	else if (entry.pNotification->GetRequestID() == reqId_interactiveLogin) {
 		auto & notification = static_cast<CInteractiveLoginNotification&>(*entry.pNotification.get());
 
-		if (CLoginManager::Get().GetPassword(notification.server, true, wxString(), notification.GetChallenge()))
+		if (notification.IsRepeated()) {
+			CLoginManager::Get().CachedPasswordFailed(notification.server, notification.GetChallenge());
+		}
+		bool canRemember = notification.GetType() == CInteractiveLoginNotification::keyfile;
+
+		if (CLoginManager::Get().GetPassword(notification.server, true, wxString(), notification.GetChallenge(), canRemember))
 			notification.passwordSet = true;
 		else {
 			// Retry with prompt
@@ -149,7 +154,7 @@ bool CAsyncRequestQueue::ProcessNextRequest()
 			if (!CheckWindowState())
 				return false;
 
-			if (CLoginManager::Get().GetPassword(notification.server, false, wxString(), notification.GetChallenge()))
+			if (CLoginManager::Get().GetPassword(notification.server, false, wxString(), notification.GetChallenge(), canRemember))
 				notification.passwordSet = true;
 		}
 
@@ -194,7 +199,7 @@ bool CAsyncRequestQueue::ProcessFileExistsNotification(t_queueEntry &entry)
 	auto & notification = static_cast<CFileExistsNotification&>(*entry.pNotification.get());
 
 	// Get the action, go up the hierarchy till one is found
-	enum CFileExistsNotification::OverwriteAction action = notification.overwriteAction;
+	CFileExistsNotification::OverwriteAction action = notification.overwriteAction;
 	if (action == CFileExistsNotification::unknown)
 		action = CDefaultFileExistsDlg::GetDefault(notification.download);
 	if (action == CFileExistsNotification::unknown) {
@@ -202,7 +207,7 @@ bool CAsyncRequestQueue::ProcessFileExistsNotification(t_queueEntry &entry)
 		if (option <= CFileExistsNotification::unknown || option >= CFileExistsNotification::ACTION_COUNT)
 			action = CFileExistsNotification::ask;
 		else
-			action = (enum CFileExistsNotification::OverwriteAction)option;
+			action = static_cast<CFileExistsNotification::OverwriteAction>(option);
 	}
 
 	if (action == CFileExistsNotification::ask) {
@@ -295,11 +300,11 @@ bool CAsyncRequestQueue::ProcessFileExistsNotification(t_queueEntry &entry)
 					if (dlg.GetValue() == defaultName) {
 						wxMessageDialog dlg2(m_pMainFrame, _("You did not enter a new name for the file. Overwrite the file instead?"), _("Filename unchanged"),
 							wxYES_NO | wxNO_DEFAULT | wxICON_QUESTION | wxCANCEL);
-						int res = dlg2.ShowModal();
+						int res2 = dlg2.ShowModal();
 
-						if (res == wxID_CANCEL)
+						if (res2 == wxID_CANCEL)
 							notification.overwriteAction = CFileExistsNotification::skip;
-						else if (res == wxID_NO)
+						else if (res2 == wxID_NO)
 							continue;
 						else
 							notification.overwriteAction = CFileExistsNotification::skip;
@@ -394,8 +399,7 @@ void CAsyncRequestQueue::TriggerProcessing()
 bool CAsyncRequestQueue::CheckWindowState()
 {
 	m_timer.Stop();
-	wxMouseState mouseState = wxGetMouseState();
-	if (mouseState.LeftIsDown() || mouseState.MiddleIsDown() || mouseState.RightIsDown()) {
+	if (!wxDialogEx::CanShowPopupDialog()) {
 		m_timer.Start(100, true);
 		return false;
 	}
