@@ -40,38 +40,43 @@ public:
 	static CEditHandler* Create();
 	static CEditHandler* Get();
 
-	wxString GetLocalDirectory();
+	std::wstring GetLocalDirectory();
 
 	// This tries to deletes all temporary files.
 	// If files are locked, they won't be removed though
 	void Release();
 
-	enum fileState GetFileState(const wxString& fileName) const; // Local files
-	enum fileState GetFileState(const wxString& fileName, const CServerPath& remotePath, const CServer& server) const; // Remote files
+	fileState GetFileState(const wxString& fileName) const; // Local files
+	fileState GetFileState(const wxString& fileName, const CServerPath& remotePath, const CServer& server) const; // Remote files
 
 	// Returns the number of files in given state
 	// pServer may be set only if state isn't unknown
-	int GetFileCount(enum fileType type, enum fileState state, const CServer* pServer = 0) const;
+	int GetFileCount(fileType type, fileState state, const CServer* pServer = 0) const;
 
 	// Starts editing the given file, queues it if needed. For local files, fileName must include local path.
 	// Can be used to edit files already being added, user is prompted for action.
-	bool Edit(CEditHandler::fileType type, wxString const fileName, CServerPath const& path, CServer const& server, wxLongLong size, wxWindow* parent);
+	bool Edit(CEditHandler::fileType type, wxString const fileName, CServerPath const& path, CServer const& server, int64_t size, wxWindow* parent);
+
+	class FileData final {
+	public:
+		FileData() = default;
+		FileData(wxString const& n, int64_t s)
+			: name(n), size(s) {}
 
-	struct FileData {
 		wxString name;
-		wxLongLong size;
+		int64_t size{};
 	};
 	bool Edit(CEditHandler::fileType type, std::vector<FileData> const& data, CServerPath const& path, CServer const& server, wxWindow* parent);
 
 	// Adds the file that doesn't exist yet. (Has to be in unknown state)
 	// The initial state will be download
-	bool AddFile(enum fileType type, wxString& fileName, const CServerPath& remotePath, const CServer& server);
+	bool AddFile(fileType type, wxString& fileName, const CServerPath& remotePath, const CServer& server);
 
 	// Tries to unedit and remove file
 	bool Remove(const wxString& fileName); // Local files
 	bool Remove(const wxString& fileName, const CServerPath& remotePath, const CServer& server); // Remote files
 	bool RemoveAll(bool force);
-	bool RemoveAll(enum fileState state, const CServer* pServer = 0);
+	bool RemoveAll(fileState state, const CServer* pServer = 0);
 
 	void FinishTransfer(bool successful, const wxString& fileName);
 	void FinishTransfer(bool successful, const wxString& fileName, const CServerPath& remotePath, const CServer& server);
@@ -88,7 +93,7 @@ public:
 	 * The dangerous argument will be set to true on some filetypes,
 	 * e.g. executables.
 	 */
-	wxString CanOpen(enum fileType type, const wxString& fileName, bool &dangerous, bool& program_exists);
+	wxString CanOpen(fileType type, const wxString& fileName, bool &dangerous, bool& program_exists);
 	bool StartEditing(const wxString& file);
 	bool StartEditing(const wxString& file, const CServerPath& remotePath, const CServer& server);
 
@@ -97,12 +102,12 @@ public:
 		wxString name; // The name of the file
 		wxString file; // The actual local filename
 		fileState state;
-		CDateTime modificationTime;
+		fz::datetime modificationTime;
 		CServerPath remotePath;
 		CServer server;
 	};
 
-	const std::list<t_fileData>& GetFiles(enum fileType type) const { wxASSERT(type != none); return m_fileDataList[(type == local) ? 0 : 1]; }
+	const std::list<t_fileData>& GetFiles(fileType type) const { wxASSERT(type != none); return m_fileDataList[(type == local) ? 0 : 1]; }
 
 	bool UploadFile(const wxString& file, bool unedit);
 	bool UploadFile(const wxString& file, const CServerPath& remotePath, const CServer& server, bool unedit);
@@ -119,15 +124,15 @@ protected:
 
 	static CEditHandler* m_pEditHandler;
 
-	wxString m_localDir;
+	std::wstring m_localDir;
 
-	bool StartEditing(enum fileType type, t_fileData &data);
+	bool StartEditing(fileType type, t_fileData &data);
 
 	wxString GetCustomOpenCommand(const wxString& file, bool& program_exists);
 
 	void SetTimerState();
 
-	bool UploadFile(enum fileType type, std::list<t_fileData>::iterator iter, bool unedit);
+	bool UploadFile(fileType type, std::list<t_fileData>::iterator iter, bool unedit);
 
 	std::list<t_fileData> m_fileDataList[2];
 
