@@ -89,7 +89,7 @@ class CSearchDialogFileList : public CFileListCtrl<CGenericFileData>
 	friend class CSearchDialog;
 	friend class CSearchSortType;
 public:
-	CSearchDialogFileList(CSearchDialog* pParent, CState &state, CQueueView* pQueue);
+	CSearchDialogFileList(CSearchDialog* pParent, CQueueView* pQueue);
 
 	void clear();
 	void set_mode(CSearchDialog::search_mode mode);
@@ -133,7 +133,7 @@ private:
 // Defined in RemoteListView.cpp
 extern wxString StripVMSRevision(const wxString& name);
 
-CSearchDialogFileList::CSearchDialogFileList(CSearchDialog* pParent, CState& state, CQueueView* pQueue)
+CSearchDialogFileList::CSearchDialogFileList(CSearchDialog* pParent, CQueueView* pQueue)
 	: CFileListCtrl<CGenericFileData>(pParent, pQueue, true),
 	m_searchDialog(pParent)
 {
@@ -396,7 +396,7 @@ bool CSearchDialog::Load()
 	if (!CreateListControl(filter_name | filter_size | filter_path | filter_date))
 		return false;
 
-	m_results = new CSearchDialogFileList(this, m_state, 0);
+	m_results = new CSearchDialogFileList(this, 0);
 	ReplaceControl(XRCCTRL(*this, "ID_RESULTS", wxWindow), m_results);
 
 	m_results->SetFilelistStatusBar(pStatusBar);
@@ -703,14 +703,14 @@ void CSearchDialog::OnSearch(wxCommandEvent&)
 		local_recursion_root root;
 		root.add_dir_to_visit(m_local_search_root);
 		m_state.GetLocalRecursiveOperation()->AddRecursionRoot(std::move(root));
-		std::vector<CFilter> const filters; // Empty, recurse into everything
+		ActiveFilters const filters; // Empty, recurse into everything
 		m_state.GetLocalRecursiveOperation()->StartRecursiveOperation(CRecursiveOperation::recursive_list, filters);
 	}
 	else {
 		recursion_root root(m_remote_search_root, true);
 		root.add_dir_to_visit_restricted(m_remote_search_root, _T(""), true);
 		m_state.GetRemoteRecursiveOperation()->AddRecursionRoot(std::move(root));
-		std::vector<CFilter> const filters; // Empty, recurse into everything
+		ActiveFilters const filters; // Empty, recurse into everything
 		m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(CRecursiveOperation::recursive_list, filters, m_remote_search_root);
 	}
 
@@ -1008,11 +1008,7 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 	}
 	m_pQueue->QueueFile_Finish(start);
 
-	CRecursiveOperation::OperationMode mode;
-	if (flatten)
-		mode = start ? CRecursiveOperation::recursive_transfer_flatten : CRecursiveOperation::recursive_addtoqueue_flatten;
-	else
-		mode = start ? CRecursiveOperation::recursive_transfer : CRecursiveOperation::recursive_addtoqueue;
+	auto const mode = flatten ? CRecursiveOperation::recursive_transfer_flatten : CRecursiveOperation::recursive_transfer;
 
 	for (auto const& dir : selected_dirs) {
 		CLocalPath target_path = path;
@@ -1024,8 +1020,8 @@ void CSearchDialog::OnDownload(wxCommandEvent&)
 		root.add_dir_to_visit(dir, _T(""), target_path, false);
 		m_state.GetRemoteRecursiveOperation()->AddRecursionRoot(std::move(root));
 	}
-	std::vector<CFilter> const filters; // Empty, recurse into everything
-	m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(mode, filters, m_original_dir);
+	ActiveFilters const filters; // Empty, recurse into everything
+	m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(mode, filters, m_original_dir, start);
 }
 
 void CSearchDialog::OnUpload(wxCommandEvent&)
@@ -1090,12 +1086,8 @@ void CSearchDialog::OnUpload(wxCommandEvent&)
 	}
 	m_pQueue->QueueFile_Finish(start);
 
-	CRecursiveOperation::OperationMode mode;
-	if (flatten)
-		mode = start ? CRecursiveOperation::recursive_transfer_flatten : CRecursiveOperation::recursive_addtoqueue_flatten;
-	else
-		mode = start ? CRecursiveOperation::recursive_transfer : CRecursiveOperation::recursive_addtoqueue;
-
+	auto const mode = flatten ? CRecursiveOperation::recursive_transfer_flatten : CRecursiveOperation::recursive_transfer;
+	
 	for (auto const& dir : selected_dirs) {
 		CServerPath target_path = path;
 		if (!flatten && dir.HasParent()) {
@@ -1106,8 +1098,8 @@ void CSearchDialog::OnUpload(wxCommandEvent&)
 		root.add_dir_to_visit(dir, target_path);
 		m_state.GetLocalRecursiveOperation()->AddRecursionRoot(std::move(root));
 	}
-	std::vector<CFilter> const filters; // Empty, recurse into everything
-	m_state.GetLocalRecursiveOperation()->StartRecursiveOperation(mode, filters);
+	ActiveFilters const filters; // Empty, recurse into everything
+	m_state.GetLocalRecursiveOperation()->StartRecursiveOperation(mode, filters, start);
 }
 
 void CSearchDialog::OnEdit(wxCommandEvent&)
@@ -1202,7 +1194,7 @@ void CSearchDialog::OnDelete(wxCommandEvent&)
 
 	for (auto const& file : selected_files) {
 		CDirentry const& entry = m_results->remoteFileData_[file];
-		std::deque<wxString> files_to_delete;
+		std::deque<std::wstring> files_to_delete;
 		files_to_delete.push_back(entry.name);
 		m_state.m_pCommandQueue->ProcessCommand(new CDeleteCommand(m_results->remoteFileData_[file].path, std::move(files_to_delete)));
 	}
@@ -1217,7 +1209,7 @@ void CSearchDialog::OnDelete(wxCommandEvent&)
 		root.add_dir_to_visit(path, segment);
 		m_state.GetRemoteRecursiveOperation()->AddRecursionRoot(std::move(root));
 	}
-	std::vector<CFilter> const filters; // Empty, recurse into everything
+	ActiveFilters const filters; // Empty, recurse into everything
 	m_state.GetRemoteRecursiveOperation()->StartRecursiveOperation(CRecursiveOperation::recursive_delete, filters, m_original_dir);
 }
 
@@ -1285,7 +1277,7 @@ void CSearchDialog::SaveConditions()
 		document.remove_child(filter);
 	filter = document.append_child("Filter");
 
-	CFilterDialog::SaveFilter(filter, m_search_filter);
+	CFilterManager::SaveFilter(filter, m_search_filter);
 
 	file.Save(true);
 }
@@ -1309,4 +1301,4 @@ void CSearchDialog::OnChangeSearchMode(wxCommandEvent&)
 		}
 	}
 
-}
\ No newline at end of file
+}
