@@ -4,7 +4,6 @@
 #include "Options.h"
 #include <wx/ffile.h>
 #include <wx/log.h>
-#include <wx/base64.h>
 
 #include <libfilezilla/local_filesys.hpp>
 
@@ -168,16 +167,7 @@ wxString ConvLocal(const char *value)
 
 pugi::xml_node AddTextElement(pugi::xml_node node, const char* name, const wxString& value, bool overwrite)
 {
-	pugi::xml_node ret;
-
-	wxASSERT(node);
-
-	wxScopedCharBuffer utf8 = value.utf8_str();
-	if (utf8) {
-		ret = AddTextElementRaw(node, name, utf8, overwrite);
-	}
-
-	return ret;
+	return AddTextElementRaw(node, name, fz::to_utf8(value).c_str(), overwrite);
 }
 
 void AddTextElement(pugi::xml_node node, const char* name, int64_t value, bool overwrite)
@@ -412,23 +402,19 @@ bool GetServer(pugi::xml_node node, CServer& server)
 		if ((long)NORMAL == logonType || (long)ACCOUNT == logonType) {
 			auto  passElement = node.child("Pass");
 			if (passElement) {
-				pass = GetTextElement(passElement);
 
 				wxString encoding = GetTextAttribute(passElement, "encoding");
 
 				if (encoding == _T("base64")) {
-					wxMemoryBuffer buf = wxBase64Decode(pass);
-					if (!buf.IsEmpty()) {
-						pass = wxString::FromUTF8(static_cast<const char*>(buf.GetData()), buf.GetDataLen());
-					}
-					else {
-						pass.clear();
-					}
+					std::string decoded = fz::base64_decode(passElement.child_value());
+					pass = fz::to_wstring_from_utf8(decoded);
 				}
 				else if (!encoding.empty()) {
-					pass.clear();
 					server.SetLogonType(ASK);
 				}
+				else {
+					pass = GetTextElement(passElement);
+				}
 			}
 		} else if ((long)KEY == logonType) {
 			key = GetTextElement(node, "Keyfile");
@@ -531,22 +517,19 @@ void SetServer(pugi::xml_node node, const CServer& server)
 			if (kiosk_mode)
 				logonType = ASK;
 			else {
-				wxString pass = server.GetPass();
-				auto const& buf = pass.utf8_str(); // wxWidgets has such an ugly string API....
-				std::string utf8(buf.data(), buf.length());
-
-				wxString base64 = wxBase64Encode(utf8.c_str(), utf8.size());
-				pugi::xml_node passElement = AddTextElement(node, "Pass", base64);
+				std::string pass = fz::to_utf8(server.GetPass());
+				
+				pugi::xml_node passElement = AddTextElementRaw(node, "Pass", fz::base64_encode(pass).c_str());
 				if (passElement) {
 					SetTextAttribute(passElement, "encoding", _T("base64"));
 				}
 
-				if (server.GetLogonType() == ACCOUNT)
+				if (server.GetLogonType() == ACCOUNT) {
 					AddTextElement(node, "Account", server.GetAccount());
+				}
 			}
 		}
-		else if (server.GetLogonType() == KEY)
-		{
+		else if (server.GetLogonType() == KEY) {
 			AddTextElement(node, "Keyfile", server.GetKeyFile());
 		}
 	}
